@@ -16,13 +16,21 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 61605 2009-08-05 13:41:45Z CJP $"
-__revision__ = "$Revision: 61605 $"
+__svnid__ = "$Id: Editra.py 61778 2009-08-29 03:58:16Z CJP $"
+__revision__ = "$Revision: 61778 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+
+# Due to some methods that were added in 2.8.3 being used in a large number
+# of places Editra has become incompatable with wxPython 2.8.1.1 and earlier.
+# So ensure correct version of wxPython can be loaded
+if not hasattr(sys, 'frozen'):
+    import wxversion
+    wxversion.ensureMinimal('2.8')
+
 import base64
 import locale
 import time
@@ -38,14 +46,6 @@ try:
 except:
     import extern.events as events
 
-# Due to some methods that were added in 2.8.3 being used in a large number
-# of places Editra has become incompatable with wxPython 2.8.1.1 and earlier.
-# TODO: add a message dialog to display this, or look into the cause of the
-#       issues of using wxversion on windows.
-if not hasattr(sys, 'frozen') and wx.VERSION < (2, 8, 3, ''):
-    print "VersionError: Editra requires wxPython 2.8.3 or higher"
-    print "              Your version is %s" % wx.VERSION_STRING
-
 # Try and import a system installed version of pkg_resources else fallback to
 # the one bundled with Editra's source.
 try:
@@ -1014,6 +1014,7 @@ def _Main(opts, args):
             profiler.Profile_Set('LAST_SESSION', u'')
         else:
             frame.GetNotebook().LoadSessionFile(session)
+        del session
 
     # Unlike wxMac/wxGTK Windows doesn't post an activate event when a window
     # is first shown, so do it manually to make sure all event handlers get
