@@ -44,8 +44,8 @@ that require a sandwich like layout.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ctrlbox.py 59529 2009-03-14 14:35:40Z CJP $"
-__revision__ = "$Revision: 59529 $"
+__svnid__ = "$Id: ctrlbox.py 61789 2009-08-30 17:52:11Z CJP $"
+__revision__ = "$Revision: 61789 $"
 
 __all__ = ["ControlBox", "CTRLBOX_NAME_STR",
 
@@ -69,7 +69,7 @@ import math
 import wx
 
 # Local Imports
-from eclutil import AdjustColour
+from eclutil import AdjustColour, DrawCircleCloseBmp
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -439,6 +439,20 @@ class ControlBar(wx.PyPanel):
             self._sizer.Add(spacer, 0)
             self._sizer.Add(tool, 0, align|wx.ALIGN_CENTER_VERTICAL)
 
+    def GetControlSizer(self):
+        """Get the sizer that is used to layout the contols (horizontal sizer)
+        @return: wx.BoxSizer
+
+        """
+        return self._sizer
+
+    def GetControlSpacing(self):
+        """Get the spacing used between controls
+        @return: size tuple
+
+        """
+        return self._spacing
+
     def DoPaintBackground(self, dc, rect, color, color2):
         """Paint the background of the given rect based on the style of
         the control bar.
@@ -454,21 +468,21 @@ class ControlBar(wx.PyPanel):
                 gc = dc.GetGraphicsContext()
             else:
                 gc = wx.GraphicsContext.Create(dc)
-            grad = gc.CreateLinearGradientBrush(rect.x, .5, rect.x, rect.height,
+            grad = gc.CreateLinearGradientBrush(rect.x, .5, rect.x, rect.GetHeight(),
                                                 color2, color)
 
             gc.SetPen(gc.CreatePen(self._pen))
             gc.SetBrush(grad)
-            gc.DrawRectangle(rect.x, 0, rect.width - 0.5, rect.height - 0.5)
+            gc.DrawRectangle(rect.x, 0, rect.GetWidth() - 0.5, rect.GetHeight() - 0.5)
 
         dc.SetPen(wx.Pen(color, 1))
         # Add a border to the bottom
         if self._style & CTRLBAR_STYLE_BORDER_BOTTOM:
-            dc.DrawLine(rect.x, rect.height - 1, rect.width, rect.height - 1)
+            dc.DrawLine(rect.x, rect.GetHeight() - 1, rect.GetWidth(), rect.GetHeight() - 1)
 
         # Add a border to the top
         if self._style & CTRLBAR_STYLE_BORDER_TOP:
-            dc.DrawLine(rect.x, 1, rect.width, 1)
+            dc.DrawLine(rect.x, 1, rect.GetWidth(), 1)
 
     def OnPaint(self, evt):
         """Paint the background to match the current style
@@ -535,7 +549,6 @@ class SegmentBar(ControlBar):
         self._scolor2 = AdjustColour(self._color2, -20)
         self._spen = wx.Pen(AdjustColour(self._pen.GetColour(), -25))
         self._x_clicked_before = False
-        self._x_state = SEGMENT_STATE_NONE
 
         if wx.Platform == '__WXMAC__':
             self.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
@@ -555,11 +568,12 @@ class SegmentBar(ControlBar):
         """
         assert bmp.IsOk()
         lsize = self.GetTextExtent(label)
-        # TODO: Refactor to a Segment Class
+        # TODO: Refactor to a Segment Class to manage these data members
         self._buttons.append(dict(id=id, bmp=bmp, label=label,
                                   lsize=lsize, bsize=bmp.GetSize(),
                                   bx1=0, bx2=0, opts=0,
-                                  selected=False))
+                                  selected=False,
+                                  x_state=SEGMENT_STATE_NONE))
         self.InvalidateBestSize()
         self.Refresh()
 
@@ -575,10 +589,10 @@ class SegmentBar(ControlBar):
         """
         button = self._buttons[bidx]
         rect = self.GetRect()
-        height = rect.height
+        height = rect.GetHeight()
         bsize = button['bsize']
 
-        bxpos = ((self._segsize[0] / 2) - (bsize.width / 2)) + xpos
+        bxpos = ((self._segsize[0] / 2) - (bsize.GetWidth() / 2)) + xpos
         bpos = (bxpos, SegmentBar.VPAD)
         rside = xpos + self._segsize[0]
         brect = wx.Rect(xpos, 0, rside - xpos, height)
@@ -627,46 +641,43 @@ class SegmentBar(ControlBar):
 
     def DoDrawCloseBtn(self, gcdc, button, rect):
         """Draw the close button on the segment
-        @param dc: Device Context
+        @param gcdc: Device Context
         @param button: Segment Dict
         @param rect: Segment Rect
 
         """
-        brush = gcdc.GetBrush()
-
-        if button['selected']:
-            gcdc.SetBrush(wx.Brush(self._scolor2))
-        else:
-            gcdc.SetBrush(wx.Brush(self._color2))
-
         if button['opts'] & SEGBTN_OPT_CLOSEBTNL:
             x = rect.x + 8
             y = rect.y + 6
         else:
-            x = (rect.x + rect.width) - 8
+            x = (rect.x + rect.GetWidth()) - 8
             y = rect.y + 6
 
-#        gcdc.DrawCircle(x, y, 5)
+        color = self._scolor2
+        if button['selected']:
+            color = AdjustColour(color, -25)
+
+        if button['x_state'] == SEGMENT_STATE_X:
+            color = AdjustColour(color, -20)
+
+        gcdc.SetPen(wx.Pen(AdjustColour(color, -30)))
 
-        # Draw the X
-        pen = gcdc.GetPen()
         brect = wx.Rect(x-3, y-3, 8, 8)
-        if self._x_state == SEGMENT_STATE_X:
-            color = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
-            gcdc.SetBrush(wx.Brush(color))
-            gcdc.SetPen(wx.Pen(AdjustColour(color, -20)))
-        else:
-            gcdc.SetPen(wx.TRANSPARENT_PEN)
-
-        gcdc.DrawRectangleRect(brect)
-        gcdc.SetPen(wx.BLACK_PEN)
-        gcdc.DrawLine(brect.x+1, brect.y+1,
-                      brect.x + brect.width - 1, brect.y + brect.height - 1)
-        gcdc.DrawLine(brect.x + brect.width - 1, brect.y + 1,
-                      brect.x + 1, brect.y + brect.height - 1)
-        gcdc.SetBrush(brush)
-        gcdc.SetPen(pen)
+        bmp = DrawCircleCloseBmp(color, wx.WHITE)
+        gcdc.DrawBitmap(bmp, brect.x, brect.y)
         button['xbtn'] = brect
+        return
+    
+        # Square style button
+#        gcdc.DrawRectangleRect(brect)
+#        gcdc.SetPen(wx.BLACK_PEN)
+#        gcdc.DrawLine(brect.x+1, brect.y+1,
+#                      brect.x + brect.GetWidth() - 1, brect.y + brect.GetHeight() - 1)
+#        gcdc.DrawLine(brect.x + brect.GetWidth() - 1, brect.y + 1,
+#                      brect.x + 1, brect.y + brect.GetHeight() - 1)
+#        gcdc.SetBrush(brush)
+#        gcdc.SetPen(pen)
+#        button['xbtn'] = brect
 
     def DoGetBestSize(self):
         """Get the best size for the control"""
@@ -739,7 +750,7 @@ class SegmentBar(ControlBar):
             button = self._buttons[index]
             if self.SegmentHasCloseButton(index):
                 brect = button['xbtn']
-                trect = wx.Rect(brect.x, brect.y, brect.width+4, brect.height+4)
+                trect = wx.Rect(brect.x, brect.y, brect.GetWidth()+4, brect.GetHeight()+4)
                 if trect.Contains(pos):
                     where = SEGMENT_HT_X_BTN
                 else:
@@ -809,24 +820,31 @@ class SegmentBar(ControlBar):
         if index == -1 or not self.SegmentHasCloseButton(index):
             return
 
-        x_state = self._x_state
-        self._x_state = SEGMENT_STATE_NONE
+        button = self._buttons[index]
+        x_state = button['x_state']
+        button['x_state'] = SEGMENT_STATE_NONE
 
         if where != SEGMENT_HT_NOWHERE:
             if where == SEGMENT_HT_X_BTN:
-                self._x_state = SEGMENT_STATE_X
+                button['x_state'] = SEGMENT_STATE_X
             elif where == SEGMENT_HT_SEG:
                 # TODO: add highligh option for hover on segment
                 pass
+        else:
+            evt.Skip()
+            return
 
-        bRedrawX = x_state != self._x_state
+        # If the hover state over a segments close button
+        # has changed redraw the close button to reflect the
+        # proper state.
+        
+        bRedrawX = button['x_state'] != x_state
         if bRedrawX:
-            dc = wx.ClientDC(self)
+            dc = wx.ClientDC(self) # TODO: this has poor results on msw
             crect = self.GetClientRect()
-            button = self._buttons[index]
             brect = wx.Rect(button['bx1'], 0,
                             button['bx2'] - (button['bx1'] - 2),
-                            crect.height)
+                            crect.GetHeight())
             self.DoDrawCloseBtn(dc, button, brect)
 
         evt.Skip()
@@ -854,8 +872,8 @@ class SegmentBar(ControlBar):
         use_labels = self._style & CTRLBAR_STYLE_LABELS
         for idx, button in enumerate(self._buttons):
             npos = self.DoDrawButton(gc, npos, idx,
-                                     self._selected == idx,
-                                     use_labels)
+                                      self._selected == idx,
+                                      use_labels)
 
     def RemoveSegment(self, index):
         """Remove a segment from the bar
@@ -865,8 +883,9 @@ class SegmentBar(ControlBar):
         """
         button = self._buttons[index]
 
-        if button['bmp']:
-            button['bmp'].Destroy()
+        # TODO: wxPython 2.8.9.2 this causes a crash...
+#        if button['bmp']:
+#            button['bmp'].Destroy()
         del self._buttons[index]
 
         if self.GetSelection() == index:
