@@ -18,8 +18,8 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 61042 2009-06-13 08:21:56Z CJP $"
-__revision__ = "$Revision: 61042 $"
+__svnid__ = "$Id: ed_cmdbar.py 61817 2009-09-03 01:19:51Z CJP $"
+__revision__ = "$Revision: 61817 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -37,6 +37,7 @@ import ed_event
 import ed_msg
 import ebmlib
 import eclib
+from profiler import Profile_Get, Profile_Set
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -61,7 +62,9 @@ XButton = PyEmbeddedImage(
 ID_CLOSE_BUTTON = wx.NewId()
 ID_SEARCH_NEXT = wx.NewId()
 ID_SEARCH_PRE = wx.NewId()
+ID_FIND_ALL = wx.NewId()
 ID_MATCH_CASE = wx.NewId()
+ID_WHOLE_WORD = wx.NewId()
 ID_REGEX = wx.NewId()
 
 #-----------------------------------------------------------------------------#
@@ -79,6 +82,8 @@ class CommandBarBase(eclib.ControlBar):
 
         # Attributes
         self._parent = parent
+        self._menu = None
+        self._menu_enabled = True
         self.ctrl = None
         self.close_b = eclib.PlateButton(self, ID_CLOSE_BUTTON,
                                          bmp=XButton.GetBitmap(),
@@ -89,6 +94,8 @@ class CommandBarBase(eclib.ControlBar):
 
         # Event Handlers
         self.Bind(wx.EVT_BUTTON, self.OnClose, self.close_b)
+        self.Bind(wx.EVT_CONTEXT_MENU, self.OnContext)
+        self.Bind(wx.EVT_MENU, self.OnContextMenu)
 
     def OnClose(self, evt):
         """Handles events from the buttons on the bar
@@ -101,6 +108,89 @@ class CommandBarBase(eclib.ControlBar):
         else:
             evt.Skip()
 
+    def OnContext(self, evt):
+        """Show the custom menu"""
+        if self._menu_enabled:
+            if self._menu is None:
+                # Lazy init the menu
+                self._menu = wx.Menu(_("Customize"))
+                # Ensure the label is disabled (wxMSW Bug)
+                item = self._menu.GetMenuItems()[0]
+                self._menu.Enable(item.GetId(), False)
+
+                to_menu = list()
+                for child in self.GetChildren():
+                    if self.IsCustomizable(child):
+                        to_menu.append(child)
+
+                if len(to_menu):
+                    to_menu.sort(key=wx.Window.GetLabel)
+                    for item in to_menu:
+                        if not item.GetLabel():
+                            continue
+
+                        self._menu.Append(item.GetId(),
+                                          item.GetLabel(),
+                                          kind=wx.ITEM_CHECK)
+                        self._menu.Check(item.GetId(), item.IsShown())
+
+            self.PopupMenu(self._menu)
+        else:
+            evt.Skip()
+
+    def OnContextMenu(self, evt):
+        """Hide and Show controls"""
+        e_id = evt.GetId()
+        ctrl = self.FindWindowById(e_id)
+        if ctrl is not None:
+            self.ShowControl(ctrl.GetName(), not ctrl.IsShown())
+            self.Layout()
+
+            # Update the persistant configuration
+            key = self.GetConfigKey()
+            if key is not None:
+                cfg = Profile_Get('CTRLBAR', default=dict())
+                state = self.GetControlStates()
+                cfg[key] = state
+
+    def EnableMenu(self, enable=True):
+        """Enable the popup customization menu
+        @keyword enable: bool
+
+        """
+        self._menu_enabled = enable
+        if not enable and self._menu is not None:
+            self._menu.Destroy()
+            self._menu = None
+
+    def GetConfigKey(self):
+        """Get the key to use for the layout config persistance.
+        @return: string
+        @note: override in subclasses
+
+        """
+        return None
+
+    def GetControlStates(self):
+        """Get the map of control name id's to their shown state True/False
+        @return: dict()
+
+        """
+        state = dict()
+        for child in self.GetChildren():
+            if self.IsCustomizable(child):
+                state[child.GetName()] = child.IsShown()
+        return state
+
+    def SetControlStates(self, state):
+        """Set visibility state of the customizable controls
+        @param state: dict(ctrl_name=bool)
+
+        """
+        for name, show in state.iteritems():
+            self.ShowControl(name, show)
+        self.Layout()
+
     def Hide(self):
         """Hides the control and notifies the parent
         @postcondition: commandbar is hidden
@@ -112,6 +202,35 @@ class CommandBarBase(eclib.ControlBar):
         self._parent.nb.GetCurrentCtrl().SetFocus()
         return True
 
+    def ShowControl(self, ctrl_name, show=True):
+        """Show/Hide a control
+        @param ctrl_name: string
+        @note: assumes all left aligned controls
+
+        """
+        sizer = self.GetControlSizer()
+        next = False
+        for item in sizer.GetChildren():
+            if next:
+                if item.IsSpacer():
+                    item.Show(show)
+                break
+
+            if item.Window and item.Window.GetName() == ctrl_name:
+                item.Show(show)
+                next = True
+
+    def IsCustomizable(self, ctrl):
+        """Is the control of a type that can be customized
+        @param ctrl: wx.Window
+        @return: bool
+
+        """
+        ok = (ctrl is not self.close_b)
+        ok = ok and (isinstance(ctrl, wx.CheckBox) or \
+                     isinstance(ctrl, eclib.PlateButton))
+        return ok
+
     def SetControl(self, ctrl):
         """Set the main control of this command bar
         @param ctrl: window
@@ -141,21 +260,38 @@ class SearchBar(CommandBarBase):
         f_lbl = wx.StaticText(self, label=_("Find") + u": ")
         t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DOWN), wx.ART_MENU)
         next_btn = eclib.PlateButton(self, ID_SEARCH_NEXT, _("Next"),
-                                     t_bmp, style=eclib.PB_STYLE_NOBG)
+                                     t_bmp, style=eclib.PB_STYLE_NOBG,
+                                     name="NextBtn")
         self.AddControl(f_lbl, wx.ALIGN_LEFT)
         self.AddControl(self.ctrl, wx.ALIGN_LEFT)
         self.AddControl(next_btn, wx.ALIGN_LEFT)
 
         t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_UP), wx.ART_MENU)
         pre_btn = eclib.PlateButton(self, ID_SEARCH_PRE, _("Previous"),
-                                    t_bmp, style=eclib.PB_STYLE_NOBG)
+                                    t_bmp, style=eclib.PB_STYLE_NOBG,
+                                    name="PreBtn")
         self.AddControl(pre_btn, wx.ALIGN_LEFT)
 
-        match_case = wx.CheckBox(self, ID_MATCH_CASE, _("Match Case"))
+        t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_FIND), wx.ART_MENU)
+        fa_btn = eclib.PlateButton(self, ID_FIND_ALL, _("Find All"),
+                                   t_bmp, style=eclib.PB_STYLE_NOBG,
+                                   name="FindAllBtn")
+        self.AddControl(fa_btn)
+        fa_btn.Show(False) # Hide this button by default
+
+        match_case = wx.CheckBox(self, ID_MATCH_CASE, _("Match Case"),
+                                 name="MatchCase")
         match_case.SetValue(self.ctrl.IsMatchCase())
         self.AddControl(match_case, wx.ALIGN_LEFT)
+        match_case.Show(False) # Hide by default
 
-        regex_cb = wx.CheckBox(self, ID_REGEX, _("Regular Expression"))
+        ww_cb = wx.CheckBox(self, ID_WHOLE_WORD,
+                            _("Whole Word"), name="WholeWord")
+        ww_cb.SetValue(self.ctrl.IsWholeWord())
+        self.AddControl(ww_cb, wx.ALIGN_LEFT)
+
+        regex_cb = wx.CheckBox(self, ID_REGEX, _("Regular Expression"),
+                               name="RegEx")
         regex_cb.SetValue(self.ctrl.IsRegEx())
         self.AddControl(regex_cb, wx.ALIGN_LEFT)
 
@@ -172,6 +308,11 @@ class SearchBar(CommandBarBase):
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
         self._sctrl.RegisterClient(self)
 
+        # Set user customizable layout
+        state = Profile_Get('CTRLBAR', default=dict())
+        cfg = state.get(self.GetConfigKey(), dict())
+        self.SetControlStates(cfg)
+
     def __del__(self):
         ed_msg.Unsubscribe(self.OnThemeChange)
         self._sctrl.RemoveClient(self)
@@ -184,6 +325,8 @@ class SearchBar(CommandBarBase):
         e_id = evt.GetId()
         if e_id in [ID_SEARCH_NEXT, ID_SEARCH_PRE]:
             self.ctrl.DoSearch(e_id == ID_SEARCH_NEXT)
+        elif e_id == ID_FIND_ALL:
+            self.ctrl.FindAll()
         else:
             evt.Skip()
 
@@ -193,11 +336,13 @@ class SearchBar(CommandBarBase):
 
         """
         e_id = evt.GetId()
-        if e_id in (ID_MATCH_CASE, ID_REGEX):
+        if e_id in (ID_MATCH_CASE, ID_REGEX, ID_WHOLE_WORD):
             ctrl = self.FindWindowById(e_id)
             if ctrl != None:
                 if e_id == ID_MATCH_CASE:
                     flag = eclib.AFR_MATCHCASE
+                elif e_id == ID_WHOLE_WORD:
+                    flag = eclib.AFR_WHOLEWORD
                 else:
                     flag = eclib.AFR_REGEX
 
@@ -217,6 +362,7 @@ class SearchBar(CommandBarBase):
         """
         self.FindWindowById(ID_MATCH_CASE).SetValue(evt.IsMatchCase())
         self.FindWindowById(ID_REGEX).SetValue(evt.IsRegEx())
+        self.FindWindowById(ID_WHOLE_WORD).SetValue(evt.IsWholeWord())
 
     def OnThemeChange(self, msg):
         """Update icons when the theme has changed
@@ -239,6 +385,13 @@ class SearchBar(CommandBarBase):
             pre.Update()
             pre.Refresh()
 
+    def GetConfigKey(self):
+        """Get the key to use for the layout config persistance.
+        @return: string
+
+        """
+        return 'SearchBar'
+
 #-----------------------------------------------------------------------------#
 
 class CommandEntryBar(CommandBarBase):
@@ -263,6 +416,9 @@ class CommandEntryBar(CommandBarBase):
         if wx.Platform == '__WXMAC__':
             self.ctrl.SetSizeHints(200, 16, -1, 16)
 
+        # Setup
+        self.EnableMenu(False)
+
 #-----------------------------------------------------------------------------#
 
 class GotoLineBar(CommandBarBase):
@@ -276,6 +432,7 @@ class GotoLineBar(CommandBarBase):
                                  size=(100, -1)))
 
         # Setup
+        self.EnableMenu(False)
         go_lbl = wx.StaticText(self, label=_("Goto Line") + ": ")
         self.AddControl(go_lbl, wx.ALIGN_LEFT)
         self.AddControl(self.ctrl, wx.ALIGN_LEFT)
