@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 61179 2009-06-23 22:47:20Z CJP $"
-__revision__ = "$Revision: 61179 $"
+__svnid__ = "$Id: ed_main.py 61605 2009-08-05 13:41:45Z CJP $"
+__revision__ = "$Revision: 61605 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -417,12 +417,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             self._handlers['ui'].append((menu_id, handler))
 
-    def DoOpen(self, evt, fname=u''):
+    def DoOpen(self, evt, fname=u'', lnum=-1):
         """ Do the work of opening a file and placing it
         in a new notebook page.
         @keyword fname: can be optionally specified to open
                         a file without opening a FileDialog
         @type fname: string
+        @keyword lnum: Explicitly set the line number to open the file to
+        @type lnum: int
 
         """
         try:
@@ -457,6 +459,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self.LOG("[ed_main][info] CMD Open File: %s" % fname)
             self.nb.OpenPage(ebmlib.GetPathName(fname),
                              ebmlib.GetFileName(fname), quiet=True)
+            self.nb.GoCurrentPage()
+
+            # lnum arg is only used with command line open
+            if lnum >= 0:
+                buff = self.nb.GetCurrentCtrl()
+                buff.GotoLine(lnum)
+
             self.Raise()
 
     def GetCommandbar(self):
@@ -621,6 +630,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Skip()
             return
 
+        # TODO: detect when save fails due to encoding and prompt to
+        #       request an encoding from the user.
         for ctrl in ctrls:
             fname = ebmlib.GetFileName(ctrl[1].GetFileName())
             if fname != '':
@@ -844,10 +855,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         # Save session files
         session = _PGET('LAST_SESSION')
-        if not isinstance(session, basestring):
+        if not isinstance(session, basestring) or not len(session):
             session = os.path.join(CONFIG['SESSION_DIR'], u"__default.session")
         _PSET('LAST_SESSION', session)
-        self.nb.SaveSessionFile(session)
+        result = self.nb.SaveSessionFile(session)
+        if result is not None:
+            pass # TODO: report error?
 
         # Cleanup Controls
         self._exiting = True
@@ -1089,6 +1102,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Special handling for common clipboard related actions
         has_focus = self.FindFocus()
+        is_stc = isinstance(has_focus, wx.stc.StyledTextCtrl)
         if has_focus is not None:
             if e_id == ID_PASTE and hasattr(has_focus, 'Paste'):
                 has_focus.Paste()
@@ -1096,12 +1110,20 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             elif e_id == ID_CYCLE_CLIPBOARD:
                 start, end = has_focus.GetSelection()
                 start, end = min(start, end), max(start, end)
-                txt = has_focus.GetRange(start, end)
+
+                if is_stc:
+                    txt = has_focus.GetTextRange(start, end)
+                elif hasattr(has_focus, 'GetRange'):
+                    txt = has_focus.GetRange(start, end)
+                else:
+                    self.LOG("[ed_main][warn] no range meth in cycle clipboard")
+                    return
+
                 if not MainWindow.CLIPBOARD.IsAtIndex(txt):
                     MainWindow.CLIPBOARD.Reset()
 
                 next = MainWindow.CLIPBOARD.GetNext()
-                if isinstance(has_focus, wx.stc.StyledTextCtrl):
+                if is_stc:
                     has_focus.ReplaceSelection(next)
                 elif hasattr(has_focus, 'Replace'):
                     has_focus.Replace(start, end, next)
@@ -1112,13 +1134,19 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 return
             elif e_id == ID_CUT and hasattr(has_focus, 'Cut'):
                 start, end = has_focus.GetSelection()
-                txt = has_focus.GetRange(start, end)
+                if is_stc:
+                    txt = has_focus.GetTextRange(start, end)
+                elif hasattr(has_focus, 'GetRange'):
+                    txt = has_focus.GetRange(start, end)
                 MainWindow.CLIPBOARD.Put(txt)
                 has_focus.Cut()
                 return
             elif e_id == ID_COPY and hasattr(has_focus, 'Copy'):
                 start, end = has_focus.GetSelection()
-                txt = has_focus.GetRange(start, end)
+                if is_stc:
+                    txt = has_focus.GetTextRange(start, end)
+                elif hasattr(has_focus, 'GetRange'):
+                    txt = has_focus.GetRange(start, end)
                 MainWindow.CLIPBOARD.Put(txt)
                 has_focus.Copy()
                 return
