@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 61142 2009-06-20 05:28:36Z CJP $"
-__revision__ = "$Revision: 61142 $"
+__svnid__ = "$Id: ed_pages.py 61471 2009-07-20 13:46:17Z CJP $"
+__revision__ = "$Revision: 61471 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -306,7 +306,8 @@ class EdPages(FNB.FlatNotebook):
         try:
             f_handle = open(session, 'wb')
         except (IOError, OSError), msg:
-            return (_("Error Saving Session File"),  ed_txt.DecodeString(msg))
+            smsg = str(msg)
+            return (_("Error Saving Session File"),  ed_txt.DecodeString(smsg))
 
         try:
             sdata = dict(win1=self.GetFileNames())
@@ -389,7 +390,6 @@ class EdPages(FNB.FlatNotebook):
         """
         self.Freeze()
         self.control = ed_editv.EdEditorView(self, wx.ID_ANY)
-        self.control.SetEncoding(Profile_Get('ENCODING'))
         self.LOG("[ed_pages][evt] New Page Created ID: %d" % self.control.GetId())
         self.AddPage(self.control)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
@@ -643,7 +643,7 @@ class EdPages(FNB.FlatNotebook):
                            self.control.GetFileName(),
                            context=self.frame.GetId())
 
-        if Profile_Get('WARN_EOL', default=True):
+        if Profile_Get('WARN_EOL', default=True) and not fileobj.IsRawBytes():
             self.control.CheckEOL()
 
     def OpenPage(self, path, filename, quiet=False):
@@ -729,7 +729,6 @@ class EdPages(FNB.FlatNotebook):
                 control.Destroy()
             else:
                 # We where using an existing buffer so reset it
-                "CLEARED IT"
                 control.SetText('')
                 control.SetDocument(ed_txt.EdFile())
                 control.SetSavePoint()
@@ -764,7 +763,7 @@ class EdPages(FNB.FlatNotebook):
         else:
             self.SetPageImage(cpage, str(self.control.GetLangId()))
 
-        if Profile_Get('WARN_EOL', default=True):
+        if Profile_Get('WARN_EOL', default=True) and not doc.IsRawBytes():
             self.control.CheckEOL()
 
         if not control.IsLoading():
@@ -777,7 +776,10 @@ class EdPages(FNB.FlatNotebook):
 
     def DoPostLoad(self):
         """Perform post file open actions"""
-        if Profile_Get('SAVE_POS'):
+        # Set last known caret position if the user setting is enabled
+        # and the caret position has not been changed during a threaded
+        # file loading operation.
+        if Profile_Get('SAVE_POS') and self.control.GetCurrentPos() <= 0:
             pos = self.DocMgr.GetPos(self.control.GetFileName())
             self.control.SetCaretPos(pos)
             self.control.ScrollToColumn(0)
