@@ -15,8 +15,8 @@ text documents and files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 61516 2009-07-24 20:05:13Z CJP $"
-__revision__ = "$Revision: 61516 $"
+__svnid__ = "$Id: ed_search.py 61781 2009-08-29 15:45:54Z CJP $"
+__revision__ = "$Revision: 61781 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -128,7 +128,7 @@ class SearchController(object):
     def __del__(self):
         """Cleanup message handlers"""
         ed_msg.Unsubscribe(self._OnShowFindMsg)
-        if self._finddlg is not None:
+        if isinstance(self._finddlg, wx.Window):
             self._finddlg.Destroy()
 
     def _CreateNewDialog(self, e_id):
@@ -820,6 +820,12 @@ class EdSearchCtrl(wx.SearchCtrl):
             data.SetFlags(self._flags)
             self.FindService.RefreshControls()
 
+    def FindAll(self):
+        """Fire off a FindAll job in the current buffer"""
+        evt = eclib.FindEvent(eclib.edEVT_FIND_ALL, flags=self._flags)
+        evt.SetFindString(self.GetValue())
+        self.FindService.OnFindAll(evt)
+
     def DoSearch(self, next=True):
         """Do the search and move the selection
         @keyword next: search next or previous
