@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 61142 2009-06-20 05:28:36Z CJP $"
-__revision__ = "$Revision: 61142 $"
+__svnid__ = "$Id: ed_stc.py 61503 2009-07-23 02:31:42Z CJP $"
+__revision__ = "$Revision: 61503 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -738,6 +738,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
             self.WordLeftExtend()
             self.SetCurrentPos(self.GetCurrentPos() + len(self.GetEOLChar()))
 
+    @jumpaction
     def OnLeftUp(self, evt):
         """Set primary selection and inform mainwindow that cursor position
         has changed.
@@ -1696,7 +1697,12 @@ class EditraStc(ed_basestc.EditraBaseStc):
                               style=wx.OK|wx.CENTER|wx.ICON_WARNING)
                 return True
             else:
-                self.File.Write(self.GetText())
+                if not self.File.IsRawBytes():
+                    self.File.Write(self.GetText())
+                else:
+                    nchars = self.GetTextLength()
+                    txt = self.GetStyledText(0, nchars)[0:nchars*2:2]
+                    self.File.Write(txt)
         except Exception, msg:
             result = False
             self.LOG("[ed_stc][err] There was an error saving %s" % path)
