@@ -20,8 +20,8 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 59503 2009-03-13 02:21:14Z CJP $"
-__revision__ = "$Revision: 59503 $"
+__svnid__ = "$Id: ed_style.py 61517 2009-07-24 20:28:44Z CJP $"
+__revision__ = "$Revision: 61517 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -54,6 +54,7 @@ class StyleItem(object):
            will require changes to the StyleMgr and Editor as well.
 
     """
+    __slots__ = ('null', 'fore', 'face', 'back', 'size', '_exattr')
     def __init__(self, fore=wx.EmptyString, back=wx.EmptyString,
                        face=wx.EmptyString, size=wx.EmptyString,
                        ex=list()):
@@ -85,6 +86,8 @@ class StyleItem(object):
         self.size = u""        # Font point size
         self._exattr = list()   # Extra attributes
 
+        # Necessary to support old style assignments...
+        # TODO: Drop support in future
         for attr, value in (("fore", fore), ("face", face),
                             ("back", back), ("size", size)):
             self.SetNamedAttr(attr, value)
@@ -693,7 +696,7 @@ class StyleMgr(object):
         ## Build style data tree
         # Tree Level 1 split tag from data
         style_tree = [style.split(u"{") for style in style_data.split(u'}')]
-        if len(style_tree) and style_tree[-1][0] == wx.EmptyString:
+        if len(style_tree) and len(style_tree[-1]) and not style_tree[-1][0]:
             style_tree.pop()
 
         # Check for Level 1 Syntax Errors
@@ -990,8 +993,17 @@ class StyleMgr(object):
         sback = self.GetItemByName('select_style')
         if not sback.IsNull():
             sback = sback.GetBack()
+            sback = eclib.HexToRGB(sback)
+            sback = wx.Colour(*sback)
         else:
             sback = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+
+        # If selection colour is dark make the foreground white
+        # else use the default settings.
+        if sum(sback.Get()) < 384:
+            self.SetSelForeground(True, wx.WHITE)
+        else:
+            self.SetSelForeground(False, wx.BLACK)
         self.SetSelBackground(True, sback)
 
         wspace = self.GetItemByName('whitespace_style')
