@@ -12,8 +12,8 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 61504 2009-07-23 03:39:28Z CJP $"
-__revision__ = "$Revision: 61504 $"
+__svnid__ = "$Id: ed_txt.py 61797 2009-09-01 11:42:10Z CJP $"
+__revision__ = "$Revision: 61797 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -135,7 +135,7 @@ class EdFile(ebmlib.FileObjectImpl):
         try:
             if self.bom is not None:
                 Log("[ed_txt][info] Stripping %s BOM from text" % self.encoding)
-                ustr = ustr.replace(self.bom, '', 1)
+                bytes = bytes.replace(self.bom, '', 1)
 
             ustr = bytes.decode(self.encoding)
         except UnicodeDecodeError, msg:
@@ -193,7 +193,7 @@ class EdFile(ebmlib.FileObjectImpl):
                         self._magic['comment'] = enc
             else:
                 Log("[ed_txt][info] File Has %s BOM" % enc)
-                self.bom = unicode(BOM.get(enc, None), enc)
+                self.bom = BOM.get(enc, None)
 
         if enc is not None:
             self.encoding = enc
