@@ -13,8 +13,8 @@ Provides a dialog for downloading, installing and configuring plugins or Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 59956 2009-03-31 02:28:33Z CJP $"
-__revision__ = "$Revision: 59956 $"
+__cvsid__ = "$Id: plugdlg.py 60986 2009-06-10 17:23:58Z CJP $"
+__revision__ = "$Revision: 60986 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -29,6 +29,7 @@ import wx.lib.delayedresult as delayedresult
 import ed_glob
 import plugin
 import ed_event
+import ed_msg
 import util
 import ed_txt
 from profiler import Profile_Get, Profile_Set
@@ -111,16 +112,7 @@ class PluginDialog(wx.Frame):
         self._imglst = list()
 
         # Setup
-        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_PACKAGE))
-        bmp = wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_TOOLBAR, (32, 32))
-        self._imglst.append(bmp)
-        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF),
-                                       wx.ART_TOOLBAR, (32, 32))
-        self._imglst.append(bmp)
-        self._nb.SetImageList(self._imglst)
-        self._nb.SetUsePyImageList(True)
+        self.__InitImageList()
 
         self._nb.AddPage(self._cfg_pg, _("Configure"), img_id=IMG_CONFIG)
         self._nb.AddPage(self._dl_pg, _("Download"), img_id=IMG_DOWNLOAD)
@@ -145,6 +137,34 @@ class PluginDialog(wx.Frame):
         self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
 
+        # Message Handlers
+        ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
+
+    def __del__(self):
+        ed_msg.Unsubscribe(self.OnThemeChange)
+
+    def __InitImageList(self):
+        """Initialize the segmentbooks image list"""
+        dorefresh = False
+        if len(self._imglst):
+            del self._imglst
+            self._imglst = list()
+            dorefresh = True
+
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PACKAGE))
+        bmp = wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_TOOLBAR, (32, 32))
+        self._imglst.append(bmp)
+        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF),
+                                       wx.ART_TOOLBAR, (32, 32))
+        self._imglst.append(bmp)
+        self._nb.SetImageList(self._imglst)
+        self._nb.SetUsePyImageList(True)
+
+        if dorefresh:
+            self._nb.Refresh()
+
     def OnClose(self, evt):
         """Handles closing the dialog and unregistering it from
         the mainloop.
@@ -174,6 +194,10 @@ class PluginDialog(wx.Frame):
         wx.GetApp().UnRegisterWindow(repr(self))
         evt.Skip()
 
+    def OnThemeChange(self, msg):
+        """Update icons on theme change message"""
+        self.__InitImageList()
+
     def Show(self, show=True):
         """Shows the dialog
         @postcondition: Dialog is registered with the main loop and shown
@@ -321,17 +345,24 @@ class ConfigPanel(wx.Panel):
         keys = sorted([ ed_txt.DecodeString(name)
                         for name in config.keys() ],
                       key=unicode.lower)
+
         for item in keys:
             val = config[item]
             self._list.Freeze()
             mod = sys.modules.get(item)
+            dist = p_mgr.GetPluginDistro(item)
+            if dist is not None:
+                item = dist.project_name
+                version = dist.version
+            else:
+                version = str(getattr(mod, '__version__', _("Unknown")))
+
             pin = PluginData()
             pin.SetName(item)
             desc = getattr(mod, '__doc__', _("No Description Available"))
             pin.SetDescription(desc.strip())
             pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
-            pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
-
+            pin.SetVersion(version)
             pbi = PBPluginItem(self._list, mod, None, item, pin.GetVersion(),
                                pin.GetDescription(), pin.GetAuthor())
 
@@ -364,14 +395,22 @@ class ConfigPanel(wx.Panel):
                       key=unicode.lower)
         bmp = wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_TOOLBAR, (32, 32))
         msg = _("This plugin requires a newer version of Editra.")
+
         for item in keys:
             val = errors[item]
             self._list.Freeze()
             mod = sys.modules.get(val)
+            dist = p_mgr.GetPluginDistro(item)
+            if dist is not None:
+                item = dist.project_name
+                version = dist.version
+            else:
+                version = str(getattr(mod, '__version__', _("Unknown")))
+
             pin = PluginData()
             pin.SetName(item)
             pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
-            pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
+            pin.SetVersion(version)
             pbi = PluginErrorItem(self._list, bmp, item, pin.GetVersion(),
                                   msg, pin.GetAuthor())
 
