@@ -60,8 +60,8 @@ memory is not likely to be very large.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: plugin.py 56178 2008-10-09 02:10:37Z CJP $"
-__revision__ = "$Revision: 56178 $"
+__svnid__ = "$Id: plugin.py 60986 2009-06-10 17:23:58Z CJP $"
+__revision__ = "$Revision: 60986 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -71,7 +71,7 @@ import wx
 
 # Editra Libraries
 import ed_glob
-from ed_txt import DecodeString
+from ed_txt import EncodeString
 import util
 from profiler import CalcVersionValue
 
@@ -227,6 +227,39 @@ class Plugin(object):
 
 #-----------------------------------------------------------------------------#
 
+class PluginConfigObject(object):
+    """Plugin configuration object. Plugins that wish to provide a
+    configuration panel should implement a subclass of this object
+    in their __init__ module. The __init__ module must also have a
+    function 'GetConfigObject' that returns an instance of this
+    class.
+
+    """
+    def GetConfigPanel(self, parent):
+        """Get the configuration panel for this plugin
+        @param parent: parent window for the panel
+        @return: wxPanel
+
+        """
+        raise NotImplementedError
+
+    def GetBitmap(self):
+        """Get the 32x32 bitmap to show in the config dialog
+        @return: wx.Bitmap
+        @note: Optional if not implemented default icon will be used
+
+        """
+        return wx.NullBitmap
+
+    def GetLabel(self):
+        """Get the display label for the configuration
+        @return: string
+
+        """
+        raise NotImplementedError
+
+#-----------------------------------------------------------------------------#
+
 class PluginData(object):
     """A storage class for representing data about a Plugin
     @see: L{Plugin}
@@ -341,13 +374,17 @@ class PluginManager(object):
         self.LOG = wx.GetApp().GetLog()
         self._config = self.LoadPluginConfig() # Enabled/Disabled Plugins
         self._pi_path = list(set([ed_glob.CONFIG['PLUGIN_DIR'], 
-                             ed_glob.CONFIG['SYS_PLUGIN_DIR']]))
+                                  ed_glob.CONFIG['SYS_PLUGIN_DIR']]))
         sys.path.extend(self._pi_path)
         self._env = self.CreateEnvironment(self._pi_path)
+
+        # TODO: combine all of these into single object
         self._plugins = dict()      # Set of available plugins
         self._enabled = dict()      # Set of enabled plugins
+        self._distros = dict()      # Set of distrobution objects
         self._loaded = list()       # List of 
-        self._obsolete = list()     # Obsolete plugins list
+        self._obsolete = dict()     # Obsolete plugins list
+
         self.InitPlugins(self._env)
         self.RefreshConfig()
 
@@ -422,19 +459,19 @@ class PluginManager(object):
         in path list
         @param path: path(s) to scan for extension points
         @type path: list of path strings
-        @todo: Figure out why decoding the path with getfilesystemencoding
-               fails on some systems.
+        @note: pkgutils does not like Unicode! only send encoded strings
 
         """
         if pkg_resources != None:
-            path = [ DecodeString(pname, sys.getfilesystemencoding())
+            path = [ EncodeString(pname, sys.getfilesystemencoding())
                      for pname in path ]
+
             try:
                 env = pkg_resources.Environment(path)
             except UnicodeDecodeError, msg:
                 self.LOG("[pluginmgr][err] %s" % msg)
         else:
-            self.LOG("[pluginmgr][warn] setup tools is not installed")
+            self.LOG("[pluginmgr][warn] setuptools is not installed")
             env = dict()
         return env
 
@@ -452,13 +489,18 @@ class PluginManager(object):
 
     def EnablePlugin(self, plugin, enable=True):
         """Enables a named plugin.
-        @param plugin: plugin to enable/disable
+        @param plugin: plugin to enable/disable (case insensitive)
         @param enable: should plugin be enabled or disabled
         @precondition: plugin must be managed by this manager instance
         @postcondition: plugin is added to activate list for activation on
                         next program start.
 
         """
+        for name in self._config:
+            if name.lower() == plugin.lower():
+                plugin = name
+                break
+
         self._config[plugin] = enable
         for cls in self._enabled:
             if cls.__module__ == plugin:
@@ -485,7 +527,7 @@ class PluginManager(object):
     def GetIncompatible(self):
         """Get the list of loaded plugins that are incompatible with the
         current running version of Editra.
-        return: list of strings
+        return: dict(name=module)
 
         """
         return self._obsolete
@@ -498,6 +540,25 @@ class PluginManager(object):
         """
         return self._plugins
 
+    def GetPluginDistro(self, pname):
+        """Get the distrobution object for a given plugin name
+        @param pname: plugin name
+        @return: Distrobution
+
+        """
+        for name, distro in self._distros.iteritems():
+            if pname.lower() == name.lower():
+                return distro
+        else:
+            return None
+
+    def GetPluginDistros(self):
+        """Get the plugin distrobution objects
+        @return: dict(name=Distrobution)
+
+        """
+        return self._distros
+
     def InitPlugins(self, env):
         """Initializes the plugins that are contained in the given
         environment. After calling this the list of available plugins
@@ -511,10 +572,16 @@ class PluginManager(object):
             return
 
         pkg_env = env
+        tmploaded = [ name.lower() for name in self._loaded ]
         for name in pkg_env:
             self.LOG("[pluginmgr][info] Found plugin: %s" % name)
+            if name.lower() in tmploaded:
+                self.LOG("[pluginmgr][info] %s is already loaded" % name)
+                continue
+
             egg = pkg_env[name][0]  # egg is of type Distrobution
             egg.activate()
+            editra_version = CalcVersionValue(ed_glob.VERSION)
             for name in egg.get_entry_map(ENTRYPOINT):
                 try:
                     # Only load a given entrypoint once
@@ -523,10 +590,10 @@ class PluginManager(object):
                         cls = entry_point.load()
                         self._loaded.append(name)
                     else:
+                        self.LOG("[pluginmgr][info] Skip reloading: %s" % name)
                         continue
                 except Exception, msg:
-                    self.LOG("[pluginmgr][err] Couldn't Load %s: %s" % \
-                                                          (str(name), str(msg)))
+                    self.LOG("[pluginmgr][err] Couldn't Load %s: %s" % (name, msg))
                 else:
                     try:
                         # Only initialize plugins that haven't already been
@@ -535,10 +602,15 @@ class PluginManager(object):
                             self.LOG("[pluginmgr][info] Creating Instance of %s" % name)
                             instance = cls(self)
                             minv = CalcVersionValue(instance.GetMinVersion())
-                            if minv <= CalcVersionValue(ed_glob.VERSION):
+                            if minv <= editra_version:
                                 self._plugins[cls] = cls(self)
+                                self._distros[egg.project_name] = egg
                             else:
-                                self._obsolete.append(name)
+                                # Save plugins that are not compatible with
+                                # this version to use for notifications.
+                                self._obsolete[name] = cls.__module__
+                        else:
+                            self.LOG("[pluginmgr][info] Skip re-init of %s" % cls)
                     finally:
                         pass
 
