@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 60365 2009-04-25 23:49:16Z CJP $"
-__revision__ = "$Revision: 60365 $"
+__svnid__ = "$Id: prefdlg.py 60682 2009-05-19 00:44:55Z CJP $"
+__revision__ = "$Revision: 60682 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -131,7 +131,7 @@ class PreferencesDialog(wx.Frame):
             wx.GetApp().UnRegisterWindow(repr(self))
 
         # Save profile settings
-        profiler.Profile().Write(profiler.Profile_Get('MYPROFILE'))
+        profiler.TheProfile.Write(profiler.Profile_Get('MYPROFILE'))
 
         evt.Skip()
 
@@ -176,13 +176,7 @@ class PrefTools(eclib.SegmentBook):
 
         # Attributes
         self._imglst = list()
-        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_THEME))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_DOCPROP))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
-        self._imglst.append(MakeThemeTool(ed_glob.ID_ADVANCED))
-        self.SetImageList(self._imglst)
-        self.SetUsePyImageList(True)
+        self.__InitImgList()
 
         self.AddPage(GeneralPanel(self), _("General"),
                      img_id=self.GENERAL_PG)
@@ -199,6 +193,31 @@ class PrefTools(eclib.SegmentBook):
         self.Bind(eclib.EVT_SB_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
 
+        # Message Handlers
+        ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
+
+    def __del__(self):
+        ed_msg.Unsubscribe(self.OnThemeChange)
+
+    def __InitImgList(self):
+        """Setup the image list for the SegmentBook"""
+        dorefresh = False
+        if len(self._imglst):
+            del self._imglst
+            self._imglst = list()
+            dorefresh = True
+
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_THEME))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_DOCPROP))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_ADVANCED))
+        self.SetImageList(self._imglst)
+        self.SetUsePyImageList(True)
+
+        if dorefresh:
+            self.Refresh()
+
     def OnPageChanging(self, evt):
         sel = evt.GetSelection()
         page = self.GetPage(sel)
@@ -231,6 +250,10 @@ class PrefTools(eclib.SegmentBook):
         if evt is not None:
             evt.Skip()
 
+    def OnThemeChange(self, msg):
+        """Update icons when the theme changes"""
+        self.__InitImgList()
+
 #-----------------------------------------------------------------------------#
 
 class GeneralPanel(wx.Panel, PreferencesPanelBase):
@@ -329,6 +352,10 @@ class GeneralPanel(wx.Panel, PreferencesPanelBase):
         enc_sz.AddMany([(wx.StaticText(self, label=_("Prefered Encoding") + u":"),
                         0, wx.ALIGN_CENTER_VERTICAL), ((5, 5),), (enc_ch, 1)])
 
+        autobk_cb = wx.CheckBox(self, ed_glob.ID_PREF_AUTOBKUP,
+                             _("Automatically Backup Files"))
+        autobk_cb.SetValue(Profile_Get('AUTOBACKUP'))
+        autobk_cb.SetToolTipString(_("Backup buffer to file periodically"))
         win_cb = wx.CheckBox(self, ed_glob.ID_NEW_WINDOW,
                              _("Open files in new windows by default"))
         win_cb.SetValue(Profile_Get('OPEN_NW'))
@@ -358,7 +385,7 @@ class GeneralPanel(wx.Panel, PreferencesPanelBase):
                          0, wx.ALIGN_CENTER_VERTICAL)])
 
         # Layout items
-        sizer = wx.FlexGridSizer(19, 2, 5, 5)
+        sizer = wx.FlexGridSizer(20, 2, 5, 5)
         sizer.AddMany([((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self,
                         label=_("Startup Settings") + u": "),
@@ -375,6 +402,7 @@ class GeneralPanel(wx.Panel, PreferencesPanelBase):
                        (wx.StaticText(self, label=_("File Settings") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL), (enc_sz, 0),
                        ((5, 5),), (fhsizer, 0),
+                       ((5, 5),), (autobk_cb, 0),
                        ((5, 5),), (win_cb, 0),
                        ((5, 5),), (pos_cb, 0),
                        ((5, 5),), (chkmod_cb, 0),
@@ -407,6 +435,10 @@ class GeneralPanel(wx.Panel, PreferencesPanelBase):
             val = e_obj.GetValue()
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
             self.FindWindowById(ed_glob.ID_PREF_AUTO_RELOAD).Enable(val)
+        elif e_id == ed_glob.ID_PREF_AUTOBKUP:
+            enable = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], enable)
+            DoUpdates('EnableAutoBackup', [enable,])
         else:
             pass
         evt.Skip()
@@ -540,7 +572,7 @@ class DocGenPanel(wx.Panel):
                            choices=[_("Old Macintosh (\\r)"), _("Unix (\\n)"),
                                     _("Windows (\\r\\n)")])
         eolmode.SetSelection(Profile_Get('EOL_MODE'))
-                        
+
         eolsz.AddMany([(wx.StaticText(self,
                         label=_("Default EOL Mode") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL), ((5, 5), 0),
@@ -630,10 +662,10 @@ class DocGenPanel(wx.Panel):
         @param evt: Event that called this handler
 
         """
-        # XXX Why when running on windows this and other imports randomly 
+        # XXX Why when running on windows this and other imports randomly
         #     become None. I have been unable to reproduce this behavior myself
         #     but have recieved enough error reports about it to beleive it.
-        #     If they were actually NoneTypes the dialog would not be able to 
+        #     If they were actually NoneTypes the dialog would not be able to
         #     be shown so this is very strange!!
         global ed_glob
         if ed_glob is None:
@@ -736,6 +768,12 @@ class DocCodePanel(wx.Panel):
         ai_cb.SetValue(Profile_Get('AUTO_INDENT'))
         vi_cb = wx.CheckBox(self, ed_glob.ID_VI_MODE, _("Enable Vi Emulation"))
         vi_cb.SetValue(Profile_Get('VI_EMU'))
+        vi_ncb = wx.CheckBox(self, ed_glob.ID_VI_NORMAL_DEFAULT,
+                             _("Start in Normal Mode"))
+        vi_ncb.SetValue(Profile_Get('VI_NORMAL_DEFAULT'))
+        vi_ncb.Enable(vi_cb.GetValue())
+        vi_ncb_sz = wx.BoxSizer(wx.HORIZONTAL)
+        vi_ncb_sz.AddMany([((16, -1), 0), (vi_ncb, 0)])
 
         # Layout the controls
         sizer = wx.FlexGridSizer(14, 2, 5, 5)
@@ -754,6 +792,7 @@ class DocCodePanel(wx.Panel):
                        ((5, 5), 0), (compex_sz, 0),
                        ((5, 5), 0), (ai_cb, 0),
                        ((5, 5), 0), (vi_cb, 0),
+                       ((5, 5), 0), (vi_ncb_sz, 0),
                        ((10, 10), 0), ((10, 10), 0)])
         msizer = wx.BoxSizer(wx.HORIZONTAL)
         msizer.AddMany([((10, 10), 0), (sizer, 1, wx.EXPAND), ((10, 10), 0)])
@@ -769,6 +808,7 @@ class DocCodePanel(wx.Panel):
                     ed_glob.ID_INDENT_GUIDES, ed_glob.ID_FOLDING,
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
                     ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE,
+                    ed_glob.ID_VI_NORMAL_DEFAULT,
                     ed_glob.ID_PREF_DLEXER, ed_glob.ID_HLCARET_LINE,
                     ed_glob.ID_PREF_AUTOCOMPEX):
 
@@ -788,6 +828,10 @@ class DocCodePanel(wx.Panel):
                 cbox = self.FindWindowById(ed_glob.ID_PREF_AUTOCOMPEX)
                 if cbox is not None:
                     cbox.Enable(e_val)
+            elif e_id == ed_glob.ID_VI_MODE:
+                cbox = self.FindWindowById(ed_glob.ID_VI_NORMAL_DEFAULT)
+                if cbox is not None:
+                    cbox.Enable(e_val)
 
             if e_id == ed_glob.ID_PREF_AUTOCOMPEX:
                 meth = 'ConfigureAutoComp'
